"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.switchNotificationMode = exports.isNotificationSwitchMode = exports.getAbsoluteFilePath = exports.getTimezoneGMTString = exports.pad = exports.isGreaterEqualMinVersion = void 0;
const types_1 = require("./types");
const isGreaterEqualMinVersion = function (minimal_version, current_version) {
    if (minimal_version === undefined)
        minimal_version = "";
    if (current_version === undefined)
        current_version = "";
    minimal_version = minimal_version.replace(/\D+/g, "");
    current_version = current_version.replace(/\D+/g, "");
    if (minimal_version === "")
        return false;
    if (current_version === "")
        return false;
    let min_version = 0;
    let curr_version = 0;
    try {
        min_version = Number.parseInt(minimal_version);
    }
    catch (error) {
    }
    try {
        curr_version = Number.parseInt(current_version);
    }
    catch (error) {
    }
    if (curr_version === 0 || min_version === 0 || curr_version < min_version) {
        return false;
    }
    return true;
};
exports.isGreaterEqualMinVersion = isGreaterEqualMinVersion;
const pad = function (num) {
    const norm = Math.floor(Math.abs(num));
    return (norm < 10 ? "0" : "") + norm;
};
exports.pad = pad;
const getTimezoneGMTString = function () {
    const tzo = -new Date().getTimezoneOffset();
    const dif = tzo >= 0 ? "+" : "-";
    return `GMT${dif}${exports.pad(tzo / 60)}:${exports.pad(tzo % 60)}`;
};
exports.getTimezoneGMTString = getTimezoneGMTString;
const getAbsoluteFilePath = function (device_type, channel, filename) {
    if (device_type === types_1.DeviceType.FLOODLIGHT) {
        return `/mnt/data/Camera${String(channel).padStart(2, "0")}/${filename}.dat`;
    }
    return `/media/mmcblk0p1/Camera${String(channel).padStart(2, "0")}/${filename}.dat`;
};
exports.getAbsoluteFilePath = getAbsoluteFilePath;
const isNotificationSwitchMode = function (value, mode) {
    if (value === 1)
        value = 240;
    return (value & mode) !== 0;
};
exports.isNotificationSwitchMode = isNotificationSwitchMode;
const switchNotificationMode = function (currentValue, mode, enable) {
    let result = 0;
    if (!enable && currentValue === 1 /* ALL */) {
        currentValue = 240;
    }
    if (enable) {
        result = mode | currentValue;
    }
    else {
        result = ~mode & currentValue;
    }
    if (exports.isNotificationSwitchMode(result, types_1.NotificationSwitchMode.SCHEDULE) && exports.isNotificationSwitchMode(result, types_1.NotificationSwitchMode.APP) && exports.isNotificationSwitchMode(result, types_1.NotificationSwitchMode.GEOFENCE) && exports.isNotificationSwitchMode(result, types_1.NotificationSwitchMode.KEYPAD)) {
        result = 1; /* ALL */
    }
    return result;
};
exports.switchNotificationMode = switchNotificationMode;
//# sourceMappingURL=utils.js.map