"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TimeStampTool = exports.AVAgent = void 0;
class a {
    constructor() {
        this.runMode = false;
        this.jitter = 0;
    }
    reset() {
        this.runMode = false;
        this.jitter = 0;
    }
    isRunMode() {
        return this.runMode;
    }
    c() {
        if (this.runMode) {
            this.jitter--;
            if (this.jitter <= 0) {
                this.reset();
            }
        }
    }
}
class JitterMan {
    constructor() {
        this.DEFAULT_DELAY_TIME = 2500;
        this.DEFAULT_DELAY_TIME_DOORBELL = 2000;
        this.MIN_PACKET_NUM = 15;
        this.SAMPLING_NUM = 30;
        this.calculate_time_stamp = 0;
        this.judge_time_stamp = 0;
        this.judge_time_stamp_doorbell = 0;
        this.judge_video_buffer_len = 0;
        this.mHasReportDelay = false;
        this.mJitterSize = 0;
        this.mRunMode = new a();
        this.mRunModeDoorbell = new a();
        this.mSamplingList = [];
    }
    reset() {
        this.mHasReportDelay = false;
        this.mRunMode.reset();
        this.mRunModeDoorbell.reset();
        this.mSamplingList = [];
        this.mJitterSize = 0;
        this.judge_time_stamp = 0;
        this.judge_time_stamp_doorbell = 0;
        this.judge_video_buffer_len = 0;
    }
    addSampling(sample) {
        const size = this.mSamplingList.length;
        if (size >= 30) {
            this.mSamplingList = this.mSamplingList.slice(0, -1);
        }
        this.mSamplingList.unshift(sample);
    }
    calculateJitter() {
        const currentTimeMillis = new Date().getTime();
        if (currentTimeMillis - this.calculate_time_stamp < 1000) {
            return;
        }
        this.calculate();
        this.calculate_time_stamp = currentTimeMillis;
    }
    calculate() {
        const tmpArray = Object.assign([], this.mSamplingList);
        if (this.mSamplingList.length >= 30) {
            tmpArray.sort();
            this.mJitterSize = Math.abs(tmpArray[0] - tmpArray[tmpArray.length - 1]);
        }
    }
    judgeRunmode(bufferLen, audioDelay, videoDelay) {
        const currentTimeMillis = new Date().getTime();
        if (this.judge_time_stamp == 0) {
            this.judge_time_stamp = currentTimeMillis;
        }
        else if (this.judge_time_stamp >= 6000) {
            this.mRunMode.reset();
            let max = Math.max(audioDelay, 0);
            if (max == 0) {
                max = Math.max(videoDelay, 0);
            }
            if (max != 0 && max >= this.DEFAULT_DELAY_TIME) {
                const jitter = bufferLen - (this.mJitterSize >= 15 ? this.mJitterSize : 15);
                if (jitter > 0) {
                    this.mRunMode.runMode = true;
                    this.mRunMode.jitter = jitter;
                    this.judge_time_stamp = currentTimeMillis;
                }
            }
        }
    }
    judgeDoorbell(bufferLen, audioDelay, videoDelay) {
        if (!this.mRunModeDoorbell.runMode && videoDelay > 5000) {
            this.mRunModeDoorbell.runMode = true;
            this.mRunModeDoorbell.jitter = bufferLen - 16;
        }
    }
    isRunMode() {
        return this.mRunMode.isRunMode();
    }
    modeRun() {
        this.mRunMode.c();
    }
    isRunModeDoorebell() {
        return this.mRunModeDoorbell.isRunMode();
    }
    modeRunDoorebell() {
        this.mRunModeDoorbell.c();
    }
}
class AVAgent {
    constructor() {
        this.mJitterMan = new JitterMan();
        this.bufferLen = 0;
        this.preFrameVideoTime = 0;
        this.nowFrameVideoTime = 0;
        this.preFrameAudioTime = 0;
        this.nowFrameAudioTime = 0;
    }
    reset() {
        if (this.elaborateTimeout) {
            clearTimeout(this.elaborateTimeout);
        }
        this.mJitterMan.reset();
        this.preFrameVideoTime = 0;
        this.nowFrameVideoTime = 0;
        this.preFrameAudioTime = 0;
        this.nowFrameAudioTime = 0;
        this.bufferLen = 0;
    }
    isRunMode() {
        return this.mJitterMan.isRunMode();
    }
    modeRun() {
        this.mJitterMan.modeRun();
    }
    isRunModeDoorebell() {
        return this.mJitterMan.isRunModeDoorebell();
    }
    modeRunDoorebell() {
        this.mJitterMan.modeRunDoorebell();
    }
    startJitterMan(isLive) {
        if (this.elaborateTimeout) {
            clearTimeout(this.elaborateTimeout);
        }
        if (isLive) {
            this.elaborateTimeout = setTimeout(() => {
                this.elaborate();
            }, 100);
        }
    }
    elaborate() {
        this.mJitterMan.addSampling(this.bufferLen);
        this.mJitterMan.calculateJitter();
        const abs = Math.abs(this.getAudioDelay());
        const abs2 = Math.abs(this.getVideoDelay());
        this.mJitterMan.judgeRunmode(this.bufferLen, abs, abs2);
        this.mJitterMan.judgeDoorbell(this.bufferLen, abs, abs2);
        this.elaborateTimeout = setTimeout(() => {
            this.elaborate();
        }, 100);
    }
    setVideoFrame(timestamp) {
        this.preFrameVideoTime = timestamp;
    }
    getVideoFrame(timestamp) {
        this.nowFrameVideoTime = timestamp;
    }
    setAudioFrame(timestamp) {
        this.preFrameAudioTime = timestamp;
    }
    getAudioFrame(timestamp) {
        this.nowFrameAudioTime = timestamp;
    }
    getVideoDelay() {
        return this.preFrameVideoTime - this.nowFrameVideoTime;
    }
    getAudioDelay() {
        return this.preFrameAudioTime - this.nowFrameAudioTime;
    }
    setBufferLen(length) {
        this.bufferLen = length;
    }
}
exports.AVAgent = AVAgent;
class TimeStampTool {
    constructor() {
        this.MAX_DURATION = 500;
        this.delay_time = 0;
        this.local_time = 0;
        this.pre_frame_data_time = 0;
        this.pt_time = 0;
    }
    reset() {
        this.local_time = 0;
        this.pre_frame_data_time = 0;
        this.pt_time = 0;
        this.delay_time = 0;
    }
    /*public addTimeStampInRunMode(AVData aVData): void {
        if (aVData != null && aVData.type != 1 && aVData.type == 2) {
            addForVideoInRunMode(aVData);
        }
    }

    public void addTimeStamp(AVData aVData) {
        if (aVData != null && aVData.type != 1 && aVData.type == 2) {
            addForVideo(aVData);
        }
    }*/
    addForVideoInRunMode(timestamp) {
        let tmpTimestamp = timestamp - this.pre_frame_data_time;
        if (tmpTimestamp < 0 || tmpTimestamp > 500) {
            tmpTimestamp = 0;
        }
        const currentTimeMillis = new Date().getTime();
        /*this.delay_time = tmpTimestamp - Math.max(currentTimeMillis - this.local_time, 0L);
        long j2 = this.delay_time;
        if (j2 < 0 || j2 > 500) {
            this.delay_time = 0;
        }*/
        this.delay_time = 0;
        this.local_time = currentTimeMillis + this.delay_time;
        this.pre_frame_data_time = timestamp;
        this.pt_time += 0;
    }
    addForVideo(timestamp) {
        let tmpTimestamp = timestamp - this.pre_frame_data_time;
        if (tmpTimestamp < 0 || tmpTimestamp > 500) {
            tmpTimestamp = 0;
        }
        const currentTimeMillis = new Date().getTime();
        this.delay_time = tmpTimestamp - Math.max(currentTimeMillis - this.local_time, 0);
        const tmpDelayTime = this.delay_time;
        if (tmpDelayTime < 0 || tmpDelayTime > 500) {
            this.delay_time = 0;
        }
        this.local_time = currentTimeMillis + this.delay_time;
        this.pre_frame_data_time = timestamp;
        this.pt_time += tmpTimestamp;
    }
    addTimeStampDoorbell(timestamp, runMode, delay, speed = 1) {
        let tmpTimestamp = (timestamp - this.pre_frame_data_time) / speed;
        if (tmpTimestamp < 0 || tmpTimestamp > 500) {
            tmpTimestamp = 0;
        }
        const currentTimeMillis = new Date().getTime();
        let tmpTime = currentTimeMillis - this.local_time;
        /*if (tmpTimestamp != 0 && tmpTime - this.delay_time > 310) {
            e.d("dis_data_time -------" + (tmpTime - this.delay_time));
            c.a().d(new FrozenEvent(tmpTime - this.delay_time));
        }*/
        if (tmpTime < 0) {
            tmpTime = 0;
        }
        this.delay_time = tmpTimestamp - tmpTime;
        if (speed == 1) {
            this.delay_time = this.a(this.delay_time, delay);
        }
        const tmpDelay = this.delay_time;
        if (tmpDelay < 0 || tmpDelay > 500) {
            this.delay_time = 0;
        }
        if (runMode) {
            this.delay_time = 0;
            tmpTimestamp = 0;
        }
        this.local_time = currentTimeMillis + this.delay_time;
        this.pre_frame_data_time = timestamp;
        this.pt_time += tmpTimestamp;
    }
    getDelayTime() {
        return this.delay_time;
    }
    a(j, j2) {
        if (j2 >= 100) {
            return j;
        }
        const d = j * 1.2;
        return d < 310.0 ? d : j;
    }
}
exports.TimeStampTool = TimeStampTool;
//# sourceMappingURL=avagent.js.map